@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -9,13 +9,11 @@
 #include "kldap_export.h"
 
 #include <QObject>
-
-class KConfigGroup;
+#include <memory>
 class KConfig;
 
 namespace KLDAP
 {
-class LdapServer;
 class LdapClient;
 /**
  * @brief The LdapClientSearchConfig class
@@ -26,7 +24,7 @@ class KLDAP_EXPORT LdapClientSearchConfig : public QObject
     Q_OBJECT
 public:
     explicit LdapClientSearchConfig(QObject *parent = nullptr);
-    ~LdapClientSearchConfig();
+    ~LdapClientSearchConfig() override;
 
     /**
      * Returns the global config object, which stores the LdapClient configurations.
@@ -35,8 +33,7 @@ public:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    class LdapClientSearchConfigPrivate;
+    std::unique_ptr<LdapClientSearchConfigPrivate> const d;
 };
 }
-
